pub struct Frames(pub u64);Expand description
Unit of time length (of a single de-interleaved channel) in samples.
Tuple Fields
0: u64Implementations
Sourceimpl Frames
impl Frames
pub fn new(frames: u64) -> Self
Sourcepub fn to_seconds(&self, sample_rate: SampleRate) -> Seconds
pub fn to_seconds(&self, sample_rate: SampleRate) -> Seconds
Convert to the corresponding time in Seconds with the given SampleRate.
Note that this conversion is NOT lossless.
Sourcepub fn to_musical(&self, bpm: f64, sample_rate: SampleRate) -> MusicalTime
pub fn to_musical(&self, bpm: f64, sample_rate: SampleRate) -> MusicalTime
Convert to the corresponding MusicalTime.
Note that this conversion is NOT lossless.
Note that this must be re-calculated after recieving a new SampleRate.
Sourcepub fn to_super_frames(&self, sample_rate: SampleRate) -> SuperFrames
pub fn to_super_frames(&self, sample_rate: SampleRate) -> SuperFrames
Convert to the corresponding time length in SuperFrames from the given SampleRate.
This conversion IS lossless if the sample rate happens to be equal to one of the common
sample rates: 22050, 24000, 44100, 48000, 88200, 96000, 176400, or 192000. This
conversion is NOT lossless otherwise.